@@ -1,5 +1,5 @@
 package System::Command;
-$System::Command::VERSION = '1.113';
+$System::Command::VERSION = '1.114';
 use warnings;
 use strict;
 use 5.006;
@@ -46,9 +46,13 @@ sub import {
 # a few simple accessors
 {
     no strict 'refs';
-    for my $attr (qw( pid stdin stdout stderr exit signal core options )) {
+    for my $attr (qw( pid stdin stdout stderr options )) {
         *$attr = sub { return $_[0]{$attr} };
     }
+    for my $attr (qw( exit signal core )) {
+        no strict 'refs';
+        *$attr = sub { $_[0]->is_terminated(); return $_[0]{$attr} };
+    }
     for my $attr (qw( cmdline )) {
         *$attr = sub { return @{ $_[0]{$attr} } };
     }
@@ -230,6 +234,32 @@ sub new {
             for grep { !defined $o->{env}{$_} } keys %{ $o->{env} };
     }
 
+    # interactive mode requested
+    if ( $o->{interactive} ) {
+        croak "Can't run command in interactive mode: not a terminal"
+          unless -t STDIN;
+
+        system { $cmd[0] } @cmd;
+
+        my $self = bless {
+            cmdline => [@cmd],
+            options => $o,
+            stdin   => IO::Handle->new,
+            stdout  => IO::Handle->new,
+            stderr  => IO::Handle->new,
+            exit    => $? >> 8,
+            signal  => $? & 127,
+            core    => $? & 128,
+        }, $class;
+
+        defined reftype( $o->{$_} )
+          and reftype( $o->{$_} ) eq 'SCALAR'
+          and ${ $o->{$_} } = $self->{$_}
+          for qw( exit signal core );
+
+        return $self;
+    }
+
     # start the command
     my ( $pid, $in, $out, $err ) = eval { $_spawn->( $o, @cmd ); };
 
@@ -279,9 +309,17 @@ sub spawn {
     return @{ $class->new(@cmd) }{qw( pid stdin stdout stderr )};
 }
 
-# delegate those to the reaper
-sub is_terminated { $_[0]{reaper}->is_terminated() }
-sub close         { $_[0]{reaper}->close(); return $_[0]; }
+# delegate those to the reaper (when there's one)
+sub is_terminated {
+    return $_[0]{options}{interactive}
+      ? 1
+      : $_[0]{reaper}->is_terminated();
+}
+
+sub close {
+    $_[0]{reaper}->close() unless $_[0]{options}{interactive};
+    return $_[0];
+}
 
 1;
 
@@ -383,6 +421,15 @@ On some systems, some commands may close standard input on startup,
 which will cause a SIGPIPE when trying to write to it. This will raise
 an exception.
 
+=item C<interactive>
+
+If true, the command will actually be run using the L<perlfunc/system>
+builtin. If C<STDIN> is not a terminal, the constructor will die.
+
+Not reaper object will be created, and the C<stdin>, C<stdout> and
+C<stderr> filehandles will point to dummy closed handles. The C<exit>,
+C<signal> and C<core> attributes will be correctly set.
+
 =item C<setpgrp>
 
 By default, the spawned process is made the leader of its own process
@@ -433,6 +480,17 @@ the pid:
 
     System::Command cmd[!]: does-not-exist
 
+=item exit
+
+=item core
+
+=item signal
+
+The above three options can be set to point to a reference to a scalar,
+which will be automatically updated when the command is terminated. See
+the L</Accessors> section for details about what the attributes of the
+same name mean.
+
 =back
 
 The System::Command object returned by C<new()> has a number of
@@ -515,7 +573,9 @@ C<$fh> is destroyed, the subprocess will be reaped, thus avoiding zombies.
 (L<System::Command::Reaper> undertakes this process.)
 
 After the call to C<close()> or after C<is_terminated()> returns true,
-the following attributes will be defined:
+the following attributes will be defined (note that the accessors
+always run C<is_terminated()>, to improve their chance of getting
+a value if the process just finished):
 
 =over 4
 
@@ -523,16 +583,25 @@ the following attributes will be defined:
 
 The exit status of the underlying command.
 
-=item core
-
-A boolean value indicating if the command dumped core.
-
 =item signal
 
 The signal, if any, that killed the command.
 
+=item core
+
+A boolean value indicating if the command dumped core.
+
 =back
 
+Even when not having a reference to the System::Command object any more,
+it's still possible to get the C<exit>, C<core> or C<signal> values,
+using the options of the same name:
+
+    my $fh = System::Command->new( @cmd, { exit => \my $exit } )->stdout;
+
+Once the command is terminated, the C<$exit> variable will contain the
+value that would have been returned by the C<exit()> method.
+
 =head1 CAVEAT EMPTOR
 
 Note that System::Command uses C<waitpid()> to catch the status
@@ -541,8 +610,8 @@ code (or any module you C<use>) does something like the following:
 
     local $SIG{CHLD} = 'IGNORE';    # reap child processes
 
-System::Command will not be able to capture the C<exit>, C<core>
-and C<signal> attributes. It will instead set all of them to the
+System::Command will not be able to capture the C<exit>, C<signal>
+and C<core> attributes. It will instead set all of them to the
 impossible value C<-1>, and display the warning
 C<Child process already reaped, check for a SIGCHLD handler>.
 
@@ -584,6 +653,12 @@ The L<System::Command::Reaper> class was added after the addition
 of Git::Repository::Command::Reaper in L<Git::Repository::Command> 1.11.
 It was later removed from L<System::Command> version 1.03, and brought
 back from the dead to deal with the zombie apocalypse in version 1.106.
+The idea of a reaper class comes from Vincent Pit.
+
+Thanks to Tim Bunce for using L<Git::Repository> and making many
+suggestions based on his use and needs. Most of them turned into
+improvement for System::Command instead, once we figured out that the
+more general feature idea really belonged there.
 
 =head1 BUGS
 
