@@ -1,11 +1,11 @@
 package System::Command::Reaper;
-$System::Command::Reaper::VERSION = '1.113';
+$System::Command::Reaper::VERSION = '1.114';
 use strict;
 use warnings;
 use 5.006;
 
 use Carp;
-use Scalar::Util qw( weaken );
+use Scalar::Util qw( weaken reftype );
 
 use POSIX ":sys_wait_h";
 
@@ -13,10 +13,14 @@ use constant MSWin32 => $^O eq 'MSWin32';
 use constant HANDLES => qw( stdin stdout stderr );
 use constant STATUS  => qw( exit signal core );
 
-for my $attr ( HANDLES, STATUS ) {
+for my $attr ( HANDLES ) {
     no strict 'refs';
     *$attr = sub { return $_[0]{$attr} };
 }
+for my $attr ( STATUS ) {
+    no strict 'refs';
+    *$attr = sub { $_[0]->is_terminated(); return $_[0]{$attr} };
+}
 
 sub new {
     my ($class, $command, $o) = @_;
@@ -55,6 +59,8 @@ sub _reap {
 
     # REPENT/THE END IS/EXTREMELY/FUCKING/NIGH
     if ( my $reaped = waitpid( $pid, $flags ) and !exists $self->{exit} ) {
+
+        # Well, it's a puzzle because, technically, you're not alive.
         my $zed = $reaped == $pid;
         carp "Child process already reaped, check for a SIGCHLD handler"
             if !$zed && !$System::Command::QUIET && !MSWin32;
@@ -66,8 +72,16 @@ sub _reap {
             : ( -1, -1, -1 );
 
         # Who died and made you fucking king of the zombies?
-        @{ $self->{command} }{ STATUS() } = @{$self}{ STATUS() }
-            if defined $self->{command};
+        if ( defined( my $cmd = $self->{command} ) ) {
+            @{$cmd}{ STATUS() } = @{$self}{ STATUS() };
+
+            # I know you're here, because I can smell your brains.
+            my $o = $cmd->{options};
+            defined reftype( $o->{$_} )
+              and reftype( $o->{$_} ) eq 'SCALAR'
+              and ${ $o->{$_} } = $self->{$_}
+              for STATUS();
+        }
 
         # I think it's safe to assume it isn't a zombie.
         print { $self->{th} } "System::Command xit[$pid]: ",
